New Relic Provider
==================

The New Relic resource provider for Pulumi lets you use New Relic
resources in your cloud programs. To use this package, please `install
the Pulumi CLI first <https://pulumi.io>`__.

Installing
----------

This package is available in many languages in the standard packaging
formats.

Node.js (Java/TypeScript)
~~~~~~~~~~~~~~~~~~~~~~~~~

To use from JavaScript or TypeScript in Node.js, install using either
``npm``:

::

   $ npm install @pulumi/newrelic

or ``yarn``:

::

   $ yarn add @pulumi/newrelic

Python
~~~~~~

To use from Python, install using ``pip``:

::

   $ pip install pulumi_newrelic

Go
~~

To use from Go, use ``go get`` to grab the latest version of the library

::

   $ go get github.com/pulumi/pulumi-newrelic/sdk/go/...

Reference
---------

For detailed reference documentation, please visit `the API
docs <https://pulumi.io/reference/pkg/nodejs/@pulumi/newrelic/index.html>`__.
